console.log("Main JavaScript is running...");

//----------------------------------------------------------------

//APP SETUP

const app = new PIXI.Application();
//PixiJS v8 Note: await only works in an async function AND at the top level of a module (see type attribute in HTML script element)
await app.init({
     antialias: true, 
     width: 1280, 
     height: 720,
     background: 0xbaf5e7
});
//Trick: can add a pixi canvas/stage to any block element in body (e.g. by ID attribute)
const pixiHolder = document.getElementById("PixiStageContainer");
//add it to the DOM (Document Object Model)
pixiHolder.appendChild(app.canvas);

//GLOBAL VARIABLES
let activityComplete = false;
let score = 0;
console.log("Score: "+ score);

//----------------------------------------------------------------

//MAKE STAGE INTERACTIVE (to track pointer location)

// Enable interactivity!
app.stage.eventMode = 'static';
//app.stage.cursor = 'none';

// Make sure the whole canvas area is interactive, not just the circle.
app.stage.hitArea = app.screen;

//----------------------------------------------------------------//

//INTRO TEXT//

//--------------------------------------------------------------------
PIXI.Assets.add({alias: 'cheer', src: 'sounds/cheer.wav'});
PIXI.Assets.load('cheer').then(() => console.log("cheer loaded"));

PIXI.Assets.add({alias: 'pop', src: 'sounds/pop.wav'});
PIXI.Assets.load('pop').then(() => console.log("pop loaded"));

//INITIAL TEXT 

//create style
const mainTextStyle = new PIXI.TextStyle({
    fontFamily: 'verdana',
    fontSize: 32,
    fill: 'lightblue',
    fontWeight: 'bold',
    stroke: 'black',
    strokeThickness: 4,
    dropShadow: true,
    dropShadowColor: '#d42ab8',
    dropShadowBlur: 4,
    dropShadowAngle: Math.PI / 6,
    dropShadowDistance: 5,
    wordWrap: true,
    wordWrapWidth: 475,
    lineJoin: 'round',
    align: 'center',
});

const colourTextStyle = new PIXI.TextStyle({
    fontFamily: 'verdana',
    fontSize: 32,
    fill: 'grey',
    fontWeight: 'bold',
    stroke: 'black',
    strokeThickness: 4,
    wordWrap: true,
    wordWrapWidth: 475,
    lineJoin: 'round',
    align: 'center',
});

const completeTextStyle = new PIXI.TextStyle({
    fontFamily: 'verdana',
    fontSize: 45,
    fill: 'pink',
    fontWeight: 'bold',
    stroke: 'black',
    strokeThickness: 4,
    wordWrap: true,
    wordWrapWidth: 475,
    lineJoin: 'round',
    align: 'center',
});

//creating a new Text obj with a text style!
console.log("Adding Instructions Text")
const welcomeTxt = new PIXI.Text({text: "Let's learn our colours!", style: mainTextStyle});
//positioning
welcomeTxt.x = 430;
//start off stage, then tween in after
welcomeTxt.y = -200;
app.stage.addChild(welcomeTxt);
//Greensock TWEEN!
gsap.to(welcomeTxt, {pixi: {y: 230}, duration: 2, ease: "power2.out"});

console.log("Adding Instructions Text")
const welcomeTxtOj = new PIXI.Text({text: "Please press start", style: mainTextStyle});
//positioning
welcomeTxtOj.x = 470;
//start off stage, then tween in after
welcomeTxtOj.y = 800;
app.stage.addChild(welcomeTxtOj);
//Greensock TWEEN!
gsap.to(welcomeTxtOj, {pixi: {y: 450}, duration: 2, ease: "power2.out"});

const insText = new PIXI.Text({text: "Drag the coloured bubble to the correct box!", style: mainTextStyle});
insText.x = 410;
insText.y = 50;


const completeText = new PIXI.Text({text: "You did it! Good job!", style: completeTextStyle});
completeText.x = 410;
completeText.y = 300;
completeText.alpha = 0;



//------------------------------------------------------------------------------------------------------------//
//ORANGE BOX//
const orangeTxt = new PIXI.Text({text: "Orange", style: colourTextStyle});
orangeTxt.x = 60;
orangeTxt.y = 660;


const answerContainer = new PIXI.Container();
const containerShape = new PIXI.Graphics();
containerShape.roundRect( 0, 0, 150, 50, 10);
containerShape.fill(0xffffff);
containerShape.stroke({width: 4, color:0xffffff})
answerContainer.addChild(containerShape);
answerContainer.x = 50;
answerContainer.y = 660;

//------------------------------------------------------------------------------------------------------------//
//pink BOX//
const pinkTxt = new PIXI.Text({text: "Pink", style: colourTextStyle});
pinkTxt.x = 280;
pinkTxt.y = 660;


const answerContainer2 = new PIXI.Container();
const containerShape2 = new PIXI.Graphics();
containerShape2.roundRect( 0, 0, 150, 50, 10);
containerShape2.fill(0xffffff);
containerShape2.stroke({width: 4, color:0xffffff})
answerContainer2.addChild(containerShape2);
answerContainer2.x = 250;
answerContainer2.y = 660;

//------------------------------------------------------------------------------------------------------------//
//green BOX//
const greenTxt = new PIXI.Text({text: "Green", style: colourTextStyle});
greenTxt.x = 470;
greenTxt.y = 660;


const answerContainer3 = new PIXI.Container();
const containerShape3 = new PIXI.Graphics();
containerShape3.roundRect( 0, 0, 150, 50, 10);
containerShape3.fill(0xffffff);
containerShape3.stroke({width: 4, color:0xffffff})
answerContainer3.addChild(containerShape3);
answerContainer3.x = 450;
answerContainer3.y = 660;

//------------------------------------------------------------------------------------------------------------//
//purple BOX//
const purpleTxt = new PIXI.Text({text: "Purple", style: colourTextStyle});
purpleTxt.x = 660;
purpleTxt.y = 660;


const answerContainer4 = new PIXI.Container();
const containerShape4 = new PIXI.Graphics();
containerShape4.roundRect( 0, 0, 150, 50, 10);
containerShape4.fill(0xffffff);
containerShape4.stroke({width: 4, color:0xffffff})
answerContainer4.addChild(containerShape4);
answerContainer4.x = 650;
answerContainer4.y = 660;


//------------------------------------------------------------------------------------------------------------//
//red BOX//
const redTxt = new PIXI.Text({text: "Red", style: colourTextStyle});
redTxt.x = 885;
redTxt.y = 660;


const answerContainer5 = new PIXI.Container();
const containerShape5 = new PIXI.Graphics();
containerShape5.roundRect( 0, 0, 150, 50, 10);
containerShape5.fill(0xffffff);
containerShape5.stroke({width: 4, color:0xffffff})
answerContainer5.addChild(containerShape5);
answerContainer5.x = 850;
answerContainer5.y = 660;

//------------------------------------------------------------------------------------------------------------//
//blue BOX//
const blueTxt = new PIXI.Text({text: "Blue", style: colourTextStyle});
blueTxt.x = 1085;
blueTxt.y = 660;


const answerContainer6 = new PIXI.Container();
const containerShape6 = new PIXI.Graphics();
containerShape6.roundRect( 0, 0, 150, 50, 10);
containerShape6.fill(0xffffff);
containerShape6.stroke({width: 4, color:0xffffff})
answerContainer6.addChild(containerShape6);
answerContainer6.x = 1050;
answerContainer6.y = 660;






//--------------------------------------------------------------------
//START BUTTON 
const startBtn = new PIXI.Container();
const startBtnShape = new PIXI.Graphics();
//roundRect(x, y, w, h, r)
startBtnShape.roundRect(-100, -40, 200, 80, 10);
startBtnShape.fill(0xd42ab8);
startBtnShape.stroke({width: 4, color:0xffffff})
startBtn.addChild(startBtnShape);
//add text label
//create style
const btnTextStyle = new PIXI.TextStyle({
    fontFamily: 'verdana',
    fontSize: 50,
    fill: 'white',
    fontWeight: 'bold',
    stroke: 'black',
    strokeThickness: 4,
    dropShadow: true,
    dropShadowColor: '#d11616',
    dropShadowBlur: 4,
    dropShadowAngle: Math.PI / 6,
    dropShadowDistance: 1,
    lineJoin: 'round',
});
const startBtnTxt = new PIXI.Text({text: 'START', style: btnTextStyle});
startBtn.addChild(startBtnTxt);
startBtnTxt.x -= 93;
startBtnTxt.y -= 35;

//positioning
app.stage.addChildAt(startBtn, 1);
startBtn.x = 1280 /2;
startBtn.y = 720 / 2;

//--------------------------------------------------------------------
//INTERACTIVITY

//make button interactive
startBtn.eventMode = 'static';
startBtn.cursor = 'pointer';

//event listener
startBtn.addEventListener('pointerover', doRollover);
startBtn.addEventListener('pointerout', doRollout);
startBtn.addEventListener('pointerup', onStartBtnUp);


function onStartBtnUp(){
    gsap.to(welcomeTxt, {duration: 0.5, pixi: {alpha: 0}});
    gsap.to(welcomeTxtOj, {duration: 0.5, pixi: {alpha: 0}});
    startBtn.eventMode = 'none';
    
    gsap.to(startBtn, {duration: 0.5, pixi: {scale: 0}, ease: 'back.in(2)', onComplete: start});

    //call the start function
    //start();
}
//START FUNCTIONS//
function start(){
    app.stage.addChild(blueCirc);
    app.stage.addChild(redCirc);
    app.stage.addChild(greenCirc);
    app.stage.addChild(orangeCirc);
    app.stage.addChild(pinkCirc);
    app.stage.addChild(purpleCirc);
    app.stage.addChildAt(answerContainer);
    app.stage.addChildAt(answerContainer2);
    app.stage.addChildAt(answerContainer3);
    app.stage.addChildAt(answerContainer4);
    app.stage.addChildAt(answerContainer5);
    app.stage.addChildAt(answerContainer6);
    app.stage.addChild(orangeTxt);
    app.stage.addChild(pinkTxt);
    app.stage.addChild(greenTxt);
    app.stage.addChild(purpleTxt);
    app.stage.addChild(redTxt);
    app.stage.addChild(blueTxt);
    app.stage.addChild(insText);
    app.stage.addChild(completeText);
}


//----------------------------------------------------------------
//Draw circles

const blueCirc = new PIXI.Graphics();
blueCirc.circle(0, 0, 35);
blueCirc.fill(0x47b1f9);
blueCirc.x = 100;
blueCirc.y = 300;


const redCirc = new PIXI.Graphics();
redCirc.circle(0, 0, 35);
redCirc.fill(0xff3300);
redCirc.x = 300;
redCirc.y = 300;


const greenCirc = new PIXI.Graphics();
greenCirc.circle(0, 0, 35);
greenCirc.fill(0x33ff00);
//blueCirc.fill(0x000000);
greenCirc.x = 500;
greenCirc.y = 300;

const orangeCirc = new PIXI.Graphics();
orangeCirc.circle(0, 0, 35);
orangeCirc.fill(0xed5215);
//blueCirc.fill(0x000000);
orangeCirc.x = 700;
orangeCirc.y = 300;

const pinkCirc = new PIXI.Graphics();
pinkCirc.circle(0, 0, 35);
pinkCirc.fill(0xd132a7);
//blueCirc.fill(0x000000);
pinkCirc.x = 900;
pinkCirc.y = 300;

const purpleCirc = new PIXI.Graphics();
purpleCirc.circle(0, 0, 35);
purpleCirc.fill(0x7e07b5);
//blueCirc.fill(0x000000);
purpleCirc.x = 1100;
purpleCirc.y = 300;


 // Follow the pointer
//  app.stage.addEventListener('pointermove', (e) =>
//     {
//         blueCirc.position.copyFrom(e.global);
//     });


///------------------------------------------------------------
//TRACK POINTER COORDINATES AND MAKE AN OBJET FOLLOW A POINTER

//track mouse coordinates as global variables

let pointerX = 0;
let pointerY = 0;

//add event listener
app.stage.addEventListener('pointermove', onPointerMove);

//event handler function
function onPointerMove(event){
    //console.log("Mouse move... " + event.data.global);
    //assign pointer coordinates to variables
    pointerX = event.data.global.x;
    pointerY = event.data.global.y;
    //console.log("pointer x: " + pointerX);
}

//Implement drag and drop functionality
redCirc.eventMode = 'static';
redCirc.cursor = 'pointer';

blueCirc.eventMode = 'static';
blueCirc.cursor = 'pointer';

greenCirc.eventMode = 'static';
greenCirc.cursor = 'pointer';

orangeCirc.eventMode = 'static';
orangeCirc.cursor = 'pointer';

pinkCirc.eventMode = 'static';
pinkCirc.cursor = 'pointer';

purpleCirc.eventMode = 'static';
purpleCirc.cursor = 'pointer';

//event listeners for drag and drop
redCirc.addEventListener('pointerdown', startDrag);
redCirc.addEventListener('pointerup', stopDrag);
redCirc.addEventListener('pointeruppuside', stopDrag);

blueCirc.addEventListener('pointerdown', startDrag);
blueCirc.addEventListener('pointerup', stopDrag);
blueCirc.addEventListener('pointeruppuside', stopDrag);

greenCirc.addEventListener('pointerdown', startDrag);
greenCirc.addEventListener('pointerup', stopDrag);
greenCirc.addEventListener('pointeruppuside', stopDrag);

orangeCirc.addEventListener('pointerdown', startDrag);
orangeCirc.addEventListener('pointerup', stopDrag);
orangeCirc.addEventListener('pointeruppuside', stopDrag);

pinkCirc.addEventListener('pointerdown', startDrag);
pinkCirc.addEventListener('pointerup', stopDrag);
pinkCirc.addEventListener('pointeruppuside', stopDrag);

purpleCirc.addEventListener('pointerdown', startDrag);
purpleCirc.addEventListener('pointerup', stopDrag);
purpleCirc.addEventListener('pointeruppuside', stopDrag);

//rollovers
redCirc.addEventListener('pointerover', doRollover);
redCirc.addEventListener('pointerout', doRollout);
//with event handlers using currentTarget, we can reuse these functions for other interactive objects
blueCirc.addEventListener('pointerover', doRollover);
blueCirc.addEventListener('pointerout', doRollout);

greenCirc.addEventListener('pointerover', doRollover);
greenCirc.addEventListener('pointerout', doRollout);

orangeCirc.addEventListener('pointerover', doRollover);
orangeCirc.addEventListener('pointerout', doRollout);

pinkCirc.addEventListener('pointerover', doRollover);
pinkCirc.addEventListener('pointerout', doRollout);

purpleCirc.addEventListener('pointerover', doRollover);
purpleCirc.addEventListener('pointerout', doRollout);



//event handler funtions
function doRollover(event){
    let obj = event.currentTarget;
    //tween rollover effect
    gsap.to(obj, {duration: .25, pixi: {scale: 1.2}, ease: "back.out(4)"});
}

function doRollout(event){
    let obj = event.currentTarget;
    //tween rollover effect
    gsap.to(obj, {duration: .25, pixi: {scale: 1}, ease: "back.out(4)"});
}

function startDrag(event){
    //get the current target object
    let dragObject = event.currentTarget
    console.log("start drag on : " + dragObject);
    //trick: set a dragging boolean to true for the object
    dragObject.dragging = true;
    //TRICK: calculate offset between object and pointer to avoid the object 'jumping' to the pointer coordinates
    dragObject.offsetX = pointerX - dragObject.x;
    dragObject.offsetY = pointerY - dragObject.y;
    //make sure the draggable object is at the highest zIndex
    let highestIndex = app.stage.children.length - 1;
    dragObject.zIndex = highestIndex;
}

function stopDrag(event){
    //get the current target object
    let dragObject = event.currentTarget
    console.log("stop drag on : " + dragObject);
    //trick: set a dragging boolean to true for the object
    dragObject.dragging = false;
    //check specific coordinates for dragging targets
    checkDragTargets();
}

function checkDragTargets(){
    //is the red circle in the right place?
    //check location within rectangle (if condition of () are met run the code)
    if(redCirc.x > 900 && redCirc.x < 1050 && redCirc.y > 660 && redCirc.y < 740){
        
        //disable interactivity
        redCirc.dragging = false;
        redCirc.eventMode = "none";
        //tween into position
        gsap.to(redCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            gsap.to(redCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("red circle in the right place! Current score: " + score);
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("red circle not in the right place");
        //snap it back with a tween
        gsap.to(redCirc, {duration: 0.5, pixi: {x: 300, y: 300}});
    }

    if(blueCirc.x > 1100 && blueCirc.x < 1150 && blueCirc.y > 660 && blueCirc.y < 740){
        
        //disable interactivity
        blueCirc.dragging = false;
        blueCirc.eventMode = "none";
        //tween into position
        gsap.to(blueCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
            gsap.to(blueCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("blue circle in the right place! Current score: " + score);
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("blue circle not in the right place");
        //snap it back with a tween
        gsap.to(blueCirc, {duration: 0.5, pixi: {x: 100, y: 300}});
    } 

    if(purpleCirc.x > 700 && purpleCirc.x < 850 && purpleCirc.y > 660 && purpleCirc.y < 740){
        
        //disable interactivity
        purpleCirc.dragging = false;
        purpleCirc.eventMode = "none";
        //tween into position
        gsap.to(purpleCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
            gsap.to(purpleCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("purple circle in the right place! Current score: " + score);
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("purple circle not in the right place");
        //snap it back with a tween
        gsap.to(purpleCirc, {duration: 0.5, pixi: {x: 1100, y: 300}});
    } 

    if(greenCirc.x > 500 && greenCirc.x < 650 && greenCirc.y > 660 && greenCirc.y < 740){
        
        //disable interactivity
        greenCirc.dragging = false;
        greenCirc.eventMode = "none";
        //tween into position
        gsap.to(greenCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
            gsap.to(greenCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("green circle in the right place! Current score: " + score);
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("green circle not in the right place");
        //snap it back with a tween
        gsap.to(greenCirc, {duration: 0.5, pixi: {x: 500, y: 300}});
    } 

    if(orangeCirc.x > 100 && orangeCirc.x < 250 && orangeCirc.y > 660 && orangeCirc.y < 740){
        
        //disable interactivity
        orangeCirc.dragging = false;
        orangeCirc.eventMode = "none";
        //tween into position
        gsap.to(orangeCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
            gsap.to(orangeCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("orange circle in the right place! Current score: " + score);
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("orange circle not in the right place");
        //snap it back with a tween
        gsap.to(orangeCirc, {duration: 0.5, pixi: {x: 700, y: 300}});
    } 

    if(pinkCirc.x > 260 && pinkCirc.x < 400 && pinkCirc.y > 660 && pinkCirc.y < 740){
        
        //disable interactivity
        pinkCirc.dragging = false;
        pinkCirc.eventMode = "none";
        //tween into position
        gsap.to(pinkCirc, {duration: 0.25, pixi: {x: 600, y: 500, scale: 0.9}});
        
        //idea: when object dragged to correct place add 1 point, when object has above 0 points change obj visibility to 0 //
        score ++; //add one to current score
        if(score > 0){
            PIXI.sound.volume('pop', 1);
            PIXI.sound.play('pop', {singleInstance: true});
            gsap.to(pinkCirc, {duration: 0.1, pixi: {alpha: 0}});
            console.log("pink circle in the right place! Current score: " + score);
        }
        if(score === 6){
            console.log("you dragged all the objects to the correct locations");
            gsap.to(completeText, {duration: 0.5, pixi: {alpha: 1}});
            PIXI.sound.volume('cheer', 1);
            PIXI.sound.play('cheer', {singleInstance: true});
            //add text fields and play sounds, etc.
        }
    } else { 
        // *** if params are not met run this function instead
        console.log("pink circle not in the right place");
        //snap it back with a tween
        gsap.to(pinkCirc, {duration: 0.5, pixi: {x: 900, y: 300}});   
    }
}



//----------------BOTTOM OF SECTION-----------------------------//

//----------------------------------------------------------------
//TICKER LOOP/"GAME ENGINE"

//add the applications ticker object and set it to call a function on each "tick" 
app.ticker.add(onTick);

function onTick(){
    //*** make object follow pointer
    //blueCirc.x = pointerX;
    //blueCirc.y = pointerY;

    //Zeno's paradox formula: (point B - point A) / fraction


    //make red circle follow blue circle
    // redCirc.x += (blueCirc.x - redCirc.x) / 50;
    // redCirc.y += (blueCirc.y - redCirc.y) / 50;

    //make green circle follow red circle
    // greenCirc.x += (redCirc.x - greenCirc.x) / 100;
    // greenCirc.y += (redCirc.y - greenCirc.y) / 100;

    //*** MAKE OBJECT MOVE WHILE DRAGGING ***//

    // *** OFFSET TRICK CONTINUED *** //

    if (redCirc.dragging === true){
        redCirc.x = pointerX - redCirc.offsetX; //offset
        redCirc.y = pointerY - redCirc.offsetY; //offset
    }
    if (blueCirc.dragging === true){
        blueCirc.x = pointerX - blueCirc.offsetX; //offset
        blueCirc.y = pointerY - blueCirc.offsetY; //offset
    }
    if (greenCirc.dragging === true){
        greenCirc.x = pointerX - greenCirc.offsetX; //offset
        greenCirc.y = pointerY - greenCirc.offsetY; //offset
    }
    if (orangeCirc.dragging === true){
        orangeCirc.x = pointerX - orangeCirc.offsetX; //offset
        orangeCirc.y = pointerY - orangeCirc.offsetY; //offset
    }
    if (pinkCirc.dragging === true){
        pinkCirc.x = pointerX - pinkCirc.offsetX; //offset
        pinkCirc.y = pointerY - pinkCirc.offsetY; //offset
    }
    if (purpleCirc.dragging === true){
        purpleCirc.x = pointerX - purpleCirc.offsetX; //offset
        purpleCirc.y = pointerY - purpleCirc.offsetY; //offset
    }
    

    //*** make object move with keyboard controls
}

//----------------------------------------------------------------
//HELPER FUNCTIONS

//handy random number function within a range
function randomNum(min, max) {
    //return a random int between min and max
    return Math.floor(Math.random() * (max - min + 1)) + min;
}

//converts degrees to radians by Nathan Clark. Borrowed from: https://natclark.com/tutorials/javascript-degrees-to-radians/
//optional precision arg determines number of decimals
function toRadians(degrees, precision = 2) {
    let radians = parseFloat(((parseFloat(degrees) * Math.PI) / 180).toFixed(precision));
    //console.log(degrees + " degrees converted to " + radians + " radians.");
    return radians;
};

